@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "package+" "1.4.0"
+(define-package "package+" "20240823.2307"
   "Extensions for the package library."
   '((emacs "24.3"))
   :url "https://github.com/zenspider/package"
-  :commit "2729bfd012c53733d3e00267d81d849ce5aa8e2d"
-  :revdesc "2729bfd012c5"
+  :commit "c677513c61b273f3c688464b6005149aeed700ff"
+  :revdesc "c677513c61b2"
   :keywords '("extensions" "tools")
   :authors '(("Ryan Davis" . "ryand-ruby@zenspider.com"))
   :maintainers '(("Ryan Davis" . "ryand-ruby@zenspider.com")))
